==> librejs-4.7.tar.gz: librejs-4.7/tools/library-fetch-tools/build_whitelist.py <==
#Copyright (c) 2010, Mozilla Corporation
#All rights reserved.

#Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

#Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.

#Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following# disclaimer in the documentation and/or other materials provided with the distribution.

#Neither the name of the Mozilla Corporation nor the names of its
#contributors may be used to endorse or promote products derived from this
#software without specific prior written permission.

#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
#IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
#THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
#PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
#CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
#EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
#PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
#LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
#NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
#SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


import sys
import os
import os.path as pth
import hashlib

output = open("whitelist_hashes.txt", mode="w")

for root, dirs, files in os.walk(sys.argv[1]):
    for filename in files:
        path = pth.join(pth.dirname(pth.abspath(sys.argv[0])),
                        root, filename)
        hash = hashlib.sha1(open(path).read()).hexdigest()
        print path, hash
        output.write('"' + hash + '"' + ': ' + '{filename: "' + filename +  '", result: checkTypes.FREE_NONTRIVIAL_GLOBAL'  + "},\n")

output.close()

==> librejs-6.0.9.tar.gz: librejs-6.0.9/tools/library-fetch-tools/build_whitelist.py <==
#Copyright (c) 2010, Mozilla Corporation
#All rights reserved.

#Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

#Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.

#Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following# disclaimer in the documentation and/or other materials provided with the distribution.

#Neither the name of the Mozilla Corporation nor the names of its
#contributors may be used to endorse or promote products derived from this
#software without specific prior written permission.

#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
#IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
#THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
#PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
#CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
#EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
#PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
#LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
#NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
#SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


import sys
import os
import os.path as pth
import hashlib

output = open("whitelist_hashes.txt", mode="w")

for root, dirs, files in os.walk(sys.argv[1]):
    for filename in files:
        path = pth.join(pth.dirname(pth.abspath(sys.argv[0])),
                        root, filename)
        hash = hashlib.sha1(open(path).read()).hexdigest()
        print path, hash
        output.write('"' + hash + '"' + ': ' + '{"filename": "' + filename +  '", "result": 6'  + "},\n")

output.close()
